intelmq.bots.outputs.redis package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.outputs.redis package

## Submodules

## intelmq.bots.outputs.redis.output module

`intelmq.bots.outputs.redis.output.` `BOT`

  alias of `intelmq.bots.outputs.redis.output.RedisOutputBot`

class `intelmq.bots.outputs.redis.output.` `RedisOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Send events to a Redis database

  `connect`()
  `hierarchical_output` = False
  `init`()
  `process`()
  `redis_db`: int = 2
  `redis_password`: str = None
  `redis_queue`: str = None
  `redis_server_ip` = '127.0.0.1'
  `redis_server_port` = 6379
  `redis_timeout` = 5000
  `with_type` = True

## Module contents